; Copyright (c) 2018 Roman Seidl (idea and concept) and Felix Karg (implementation)
; Mail: felix.karg@uranus.uni-freiburg.de; roman.seidl@bnv-bamberg.de
; Github: github.com/fkarg
; The model is available under XY licence at OPENABM https://www.comses.net/

globals
[
  NumberPersons     ; This is the total number of agents in all the households.
  allowance         ; this is the allowed amount of Carbon per Person.
  allowpool         ; available amount of carbon-allowances to be sold.
  allowpool_new     ; this is the allowpool from the previous iteration,
                    ; meaning the 'buffer' for the simulation - since there's a random getting all over them.
  demandpool        ; total demand of all agents/households.
  BeginDemand       ; The total demand at the beginning
  alpha             ; alpha - coefficient for the formula to calculate the price for allowances to adapt for smooth development.
  price             ; the price for allowances.
  CarbonVal         ; integer value for correcting all calculations to be either based on Carbon-values or KWh-values
  savedTick         ; if this tick got saved already it can be restored (needed to save a simulation run).
  averageReduce     ; the average reduction over four weeks
  avgPrice          ; the average allowance price for all ticks
  avgAllowance      ; average amount of allowances
  avgSelling        ; the average percentage of households selling
  avgPoorSelling    ; average percentage of low-income households selling

]


turtles-own
[
  number_persons  ; this is the number of persons in a specific household.

  originald       ; an agent's original demand. Every agent can only reduce demand for carbon allowances to 70% of it's original demand. This is because for instance, bigger and more well of households always have a higher demand
  demand          ; demand is dependent on initial demand, roughly income and of course, recent changes made.
  actuald         ; this is the actual demand

  saving          ; the amount of fossile energy (and thus carbon) abated through other means, e.g. solar panels or more efficient technology - there's a limit to this correlating to 'income' and the ecological factor of the agent

  income          ; weekly income of household.

  socio-ecological; parameter that denotes how much this agent is motivated by 'socio-ecological'concerns, investing more for 'nature' and environmental reasons
  economic        ; parameter that denotes how much this agent is motivated by 'economic'concerns; investting more if it pays out; more the homo economicus
                  ; these parameters resemble the assumptions in the Consumat approach (see Janssen & Jager 2002, Jager & Janssen 2012)
  savingLsocio-ecological   ; the savinglevel of what was saved because people are socio-ecological oriented (at least some of them)
  BaseDemand      ; Demand at the beginning of each 52 week cycle
  selling         ; if this agent is selling its allowances or not - this is actually a factor ranging from 0 to 1 (initially), and is then dependent upon the general population behaviour
  actualSelling   ; if this agent is actually selling, not if it's only intending to.
  actualEconomic  ; if this agent will invest money no matter if it is required or not.

  diff            ; temp, debug-cache
]

; assumption of German mix: 527 gram of carbon (CO2-emissions) for 1 kWh (527 g/kWh). [Actually only in terms of electricity but high enough]


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

breed [households household]
to setup
  clear-all
  clear-output
  ; this will create reproducable runs:
  random-seed 9998
  create-households NumberAgents ;[fd random 20 ]
  set allowpool 0
  set NumberPersons 0
  set alpha 0.00002
  set price StartPrice
  set allowpool_new 0
  set demandpool 0
  set averageReduce 0
  set CarbonVal 2
  set avgPrice 0
  set avgAllowance 0
  set avgSelling 0
  set avgPoorSelling 0
ask patches
  [set pcolor grey - 2]
  ask households
  [
    set shape "house"
    setxy random-xcor random-ycor

    ; empiric income-values per household for each agent (from Paper [1]). For each 500€-span values were defaultet to the upper bound.
    let incomePart random-float 92.6
    set income 6000      ;  3.5 % - more than 5k, this is a arbitrarily chosen number.
    if incomePart <= 89.1 ;  3.0 %
    [ set income 5000 ]
    if incomePart <= 86.1 ;  5.4 %
    [ set income 4500 ]
    if incomePart <= 80.7 ;  6.5 %
    [ set income 4000 ]
    if incomePart <= 74.2 ;  9.8 %
    [ set income 3500 ]
    if incomePart <= 64.4 ; 12.7 %
    [ set income 3000 ]
    if incomePart <= 51.7 ; 17.9 %
    [ set income 2500 ]
    if incomePart <= 33.8 ; 15.0 %
    [ set income 2000 ]
    if incomePart <= 18.8 ; 12.3 %
    [ set income 1500 ]
    if incomePart <= 6.5  ;  5.9 %
    [ set income 1000 ]
    if incomePart <= 0.6  ;  0.6 %
    [ set income 500 ]

    ; empiric data of persons / household from Paper [1]
    let personPart random 1012
    set number_persons 5 ; 48  / 1012 - this category actually means 5 or more persons per household
    if personPart <= 964 ; 163  / 1012
    [ set number_persons 4 ]
    if personPart <= 801 ; 195 / 1012
    [ set number_persons 3 ]
    if personPart <= 606 ; 385
    [ set number_persons 2 ]
    if personPart <= 221 ; 221
    [ set number_persons 1 ]

    let factor random-float 0.4
    ; somewhat a variation even for agents with the same person_number and income

    ; rough estimate for the demand per household from Federal Environment Office (2016), page 65.
    set actuald (1.1 - number_persons * 0.05) * ((log (log income e) e) - 0.9) * 20278 * number_persons * (0.8 + factor) * 0.527; 20278 is the average across all households (of all sizes) in kWh.
    ; this double-log version from the income is actually quite an accurate correlation for this full factor ; log (log 500 e) e ~ 1.83 ; log (log 5000 e) e ~ 2.14

    ; what this agent required initially
    set originald actuald
    set BaseDemand originald
    set saving 0

    set NumberPersons NumberPersons + number_persons ; keeping the global variable updated


    let socio-ecologicalPart random-float 100.0  ; Wallace et al. (2010) - Buy other people's allowance units to enable one to use more carbon
    set socio-ecological 1
    if socio-ecologicalPart < 99.3 [ set socio-ecological 0.5 + factor ] ; 65.4 + 3.3 (Unlikely)
    if socio-ecologicalPart < 30.6 [ set socio-ecological 0.2 + factor ] ; 18.5 + 3.3 (Possibly)
    if socio-ecologicalPart < 8.8  [ set socio-ecological 0   + factor ] ; 5.5 + 3.3 (Probably)


    let sellingPart random-float 100.0 ; Wallace et al. (2010) - how likely an agent is to sell allowances
    set selling 0
    if sellingPart < 99.7 [ set selling 0.2 + factor ] ; 47.4 + 4.1 (Unlikely)
    if sellingPart < 48.2 [ set selling 0.4 + factor ] ; 25.2 + 4.1 (Possibly)
    if sellingPart < 18.9 [ set selling 0.7 + factor ] ; 14.8 + 4.1 (Probably)
    set selling min list 1 selling

    ; this is actually arbitrarily chosen. Credible sources could complement this assumption.
    set economic min list 1 (selling + (random-float 0.6) - 0.2)
    set economic max list 0 economic ; since the value could drop below 0.

    if ColorAgents = "1_income" [set color scale-color blue income 10000 0]
    if ColorAgents = "2_Ecological" [set color scale-color green socio-ecological 1 0]
    if ColorAgents = "3_numberpersons"   [set color scale-color orange number_persons 7 1]
    if ColorAgents = "4_selling"   [set color scale-color yellow selling 1 0]
    if ColorAgents = "5_difference"   [set color scale-color red diff 5000 -5000]

    ; how many people are 'actually' economic thinking? The guess here is that of those that can afford it, probably around 15%. Needs empiric backing.
    ifelse income > 3000 and random-float 1.0 < 0.15 [
      set actualEconomic true
    ] [
      set actualEconomic false
    ]


    set demand actuald - saving

  ]


  ; setting up allowances
  let temp (sum [demand] of households) / NumberPersons
  set allowance temp + Allocation_of_allowances * temp * 0.01
  set BeginDemand temp * NumberPersons


  reset-ticks ; required only here, since it'll set up the plots as well, and they require the households

  ; setting up the allowpool
  set allowpool NumberPersons * allowance * (0.5 - Allocation_of_allowances * 0.01)        ; arbitrary initial initialization. Will be overridden after first few ticks either way.
  set demandpool 0
  set allowpool_new 0
 show allowpool

set savedTick false
end


to start
  if ticks >= MaxTicks and StopAtMaxTicks [stop]

  if AutoSave [
    update_values_output
  ]

  if ticks > 0 and ticks mod 12 = 0
  [
    reduceallowance
  ]

  update_price

  ask households
  [
    ; the difference between demand for and allocated allowances
    set diff allowance * number_persons - demand

    let noa abs diff ; the value for "number of allowances" left after demand subtracted


    ; if an agent needs to buy allowances, it shall buy them if available
    if diff < 0 and (allowpool > noa) and price * CarbonVal * noa < income * IncomePercentAvailable
    [
      set allowpool allowpool - noa
      set demandpool demandpool + noa
    ]


    ; now either the allowpool is empty or teh agent cannot afford it (yellow sad face); such an agent stays yellow, even if later it can afford needed allowances (yellow house)
    ifelse diff < 0 and (allowpool < noa or price * CarbonVal * noa < income * IncomePercentAvailable) ; these 0.3
    [ set color yellow
      set shape "face sad"
      set demandpool demandpool + noa
    ]
    [ set shape "house" ]

   ; Alternatively you may use these trackers for the view.
   ; set color scale-color yellow selling 1 0
   ; set color scale-color red diff 5000 -5000


    ; also, agents certainly are not selling if they don't have anything to offer to begin with
    ifelse diff < 0
    [
      set selling max list 0 selling - random-float 0.3
      set actualSelling false
    ] [
      if (actualSelling = false) and selling > 0.8 and random-float 1.0 < 0.08
      [ set actualSelling true ]
      ; this is actually asking the other agents on the same patch and slowly all of them get to the same selling-number .... 1!
      ; that is, it takes some time for agents to realize they can sell and it makes sense; they 'learn' from other agents who already sell.
      set selling min list 1 (mean [selling] of turtles-here) * 0.1 + selling * 0.9 + 0.01
    ]

    ; now if agents actually DO sell though ...
    if diff > 0 and actualSelling = true
    [ set allowpool_new allowpool_new + diff ]



    ; they want to reduce carbon allowances demand if they are either above their allowance level or if they are pretty close to the threshold (here within 3% of the allowed amount).
   if diff < allowance * target * 0.02 and random-float 0.8 < socio-ecological [
      ; for ease of implementation, it's happening somewhere else:
      increaseSavingLevel self
    ]


    ; By investing 2000 € 1 ton of CO2 can be abated. However, costs for more reduction increase pretty fast.
    ;see also section 3.4. Assessments of efficiency in Lockwood, Matthew (2010): The economics of personal carbon trading. In: Climate Policy 10 (4), S. 447–461. DOI: 10.3763/cpol.2009.0041.
    ; This is about 2000 kWh - so roughly 1 € / kWh .
    ; But see for instance: https://journals.openedition.org/sapiens/793




    ; available saving levels:
    ; - savingLsocio-ecological    (what can be saved without investment, motivated by socio-ecological reasons, resulting in less usage)
    ; one can assume four cases: those who are indifferent (low on both scales), those with high levels of either economic or socio-ecological motivation, and some have high values for both socio-ecological and economic,
    ; those will try to invest as much as possible and try to use less energy/produce less carbon.
    ; if agents are indifferent, taht is, neither strongly economically or environmentally inspired, they are going to use whatever they want and pay for the allowances if they can afford it.
    ; also, at some point quite early we'll have people who can't afford to pay anymore, so they'll obviously try to invest some - but they're unlikely to change their livestyle.
    ; it is not expected that agents change their 'socio-ecological' attitude that much after all. They just want to get by.


    ; makes it dependent upon whether you are in the need of allowances or not. Also linked with socio-ecological factor.
    let savable 1
    set savable economic * income * 0.6 / (1.001 ^ saving * CarbonVal) ; this means that in the beginning carbon reduction costs are almost linear, but increases quite fast


    ifelse diff < allowance * 0.003 [
      set saving saving + savable * (0.8 - IncomePercentAvailable)  ; this factor reduces the saving amount if it's not absolutely required
    ] [
      if actualEconomic [
        set saving saving + savable * (0.2 + IncomePercentAvailable)   ; Most people are unlikely to spend if it's not really required. So it's just a very small percentage here.
      ]
    ]


    set demand actuald - saving

  ]
  updateReporters
  set savedTick false
  tick

end


to increaseSavingLevel [h]
  ask h
  [

    ; last but not least, what can an agent do to improve its carbon-footprint? Does it even intend to reduce it to begin with? Let's see what options we have.

    ; according to Zannini et al. an agent can reduce it's (energy) usage due to in-house changes (switching devices really off if not required, using them less, ...)
    ; more or less in four stages, each resulting in a decrease in around 2 percent each time.

    ; also, when going down with mobility, (using the car less often, doing less trips by plane or trips in total, going by public transport)
    ; there are basically two levels each inducing a decrease of around 4 percent each time.

    ; additionally, when investing in new devices and the like, it's pretty easy to save around 1Ton/Year when investing around 2000 €, however the cost is increasing pretty fast if one tries to save more.
    ; (since there's no neccessity replacing the same devices again, and the margin for most more expensive devices is less as well)

    if savingLsocio-ecological < 10 * socio-ecological and (actuald > allowance * number_persons * 1.1 or savingLsocio-ecological < 5)
    [
    ; socio-ecological is supposed to not be that high yet
    ifelse savingLsocio-ecological = 3 or savingLsocio-ecological >= 7
    [
      set actuald actuald * 0.96
        ; one could probably just fly less or do something else rather expensive to save a lot carbon, and if an agent is "socio-ecological" enough to not do it anymore you can save quite a lot.
    ] [
      set actuald actuald * 0.98
    ]
      set savingLsocio-ecological savingLsocio-ecological + 1
    ]
  ]
end


; this procedure is for the yearly reduction of the amount of allowances available
to reduceallowance
  set averageReduce -100 * mean [ (demand - BaseDemand) / BaseDemand ] of households ;this is the average amount households have reduced
  set allowance allowance - allowance * (target + sensitivity * (target - averageReduce)) / 100 ;the second term adjusts the amount reduced depending on how far away the true reduction is from the target
  ask households [set BaseDemand demand]

end


to update_values_output
  if not savedTick [
  ; Export csv files of the results
  if not file-exists? "Output-Agents.csv" or not file-exists? "Output-World.csv" [

    file-open "Output-Agents.csv"
    file-print "tick, id, income, number_persons, actuald, demand, actualSelling, diff"
    file-close

    file-open "Output-World.csv"
    file-print "tick, allowance, allowpool, demandpool, price"
    file-close
  ]
  file-open "Output-Agents.csv"
  ask households
  [
    file-print (word ticks "," who "," income "," number_persons "," actuald "," demand "," actualSelling "," (allowance - demand))
  ]
  file-close

  file-open "Output-World.csv"
  file-print (word ticks "," allowance "," allowpool_new "," demandpool "," price)
  file-close

  export-world (word "world-" ticks ".csv")
    set savedTick true
  ]
end





to update_price

  if ticks > 4 [

  ; according to p(t+1)-pt=α(Dt-St) = p_t+1 = p_t + alpha * (dempandpool - allowpool_new)
  set price price + alpha * (demandpool / NumberPersons - allowpool_new / NumberPersons)
  ]
  set allowpool allowpool_new
  set allowpool_new 0
  set demandpool 0
  ; ensure the price stays positive / price cannot fall below 0.001 but can increase limitless
  set price max list price 0.001
end

to updateReporters
  set avgPrice avgPrice + (price / MaxTicks)
  set avgAllowance avgAllowance + (allowance / MaxTicks)
  set avgSelling avgSelling + ((count households with [diff < 0]) / (NumberAgents * MaxTicks))
  set avgPoorSelling avgPoorSelling + ((count households with [diff < 0 and income < 1000]) / ((count households with [income < 1000]) * MaxTicks))
end
; values that need empiric backing:
; - Line 147, 152: the number of actual economic people in a population (percentages)
; -
;
; values that are at least somewhat empiric:
; - income distribution and values
; - distribution of Persons per households
; - carbon emissions per person per hausehold based on income and persons per household, at least correlating
; - decrease in demand of carbon emissions based on: transport, energy usage, energy-saving technology
; - the market trading (with only some people trying it at first and more later on)
; - economic and ecological investing types. (and implementation of them, but explanation following)
; -
;
@#$#@#$#@
GRAPHICS-WINDOW
330
15
767
453
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
15
10
79
43
Setup
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
90
10
175
43
NIL
Start
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
90
55
177
88
Step once
start
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
790
315
1275
517
Carbon Demand per Person (in HouseHolds)
NIL
Demand per Person
0.0
10.0
800.0
1200.0
true
true
"let t floor mean [demand / number_persons] of households\nset-plot-y-range t (t + 1)\n\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"HH 1" 1.0 0 -16777216 true "" "plot [demand / number_persons] of household 0"
"HH 2" 1.0 0 -14070903 true "" "plot [demand / number_persons] of household 1"
"HH 3" 1.0 0 -13840069 true "" "plot [demand / number_persons] of household 2"
"HH 4" 1.0 0 -4079321 true "" "plot [demand / number_persons] of household 3"
"Average" 1.0 0 -14070903 true "" "plot Mean [demand / number_persons] of households"
"Max" 1.0 2 -7500403 true "" "plot Max [demand / number_persons] of households"
"Min" 1.0 2 -955883 true "" "plot Min [demand / number_persons] of households"
"Allowed" 1.0 0 -2674135 true "" "plot allowance"
"Median" 1.0 0 -6459832 true "" "plot median [demand / number_persons] of households"

CHOOSER
10
205
140
250
NumberAgents
NumberAgents
4 40 100 200 500 1000 5000 10000 20000 30000 50000 100000 1000000
5

CHOOSER
10
260
147
305
target
target
0 0.5 1 1.5 2 2.5 3 3.5 4 4.5 5 100
10

MONITOR
1010
520
1110
565
Average Demand
Mean [demand / number_persons] of households
1
1
11

MONITOR
790
565
917
610
Available Allowances 
allowpool_new
2
1
11

SWITCH
10
755
132
788
AutoSave
AutoSave
1
1
-1000

MONITOR
790
520
905
565
Allowed C/Person
allowance
1
1
11

MONITOR
560
795
780
840
Price of 1 allowance (€)
price
4
1
11

SLIDER
10
415
207
448
Allocation_of_allowances
Allocation_of_allowances
-20
20
-10.0
0.5
1
NIL
HORIZONTAL

BUTTON
15
55
80
88
1/2 Year
start\nstart\nstart\nstart\nstart\nstart
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
10
475
215
536
Starting allowance allocation. How many % above the mean demand. Default value is 0.
12
0.0
1

SWITCH
10
105
145
138
StopAtMaxTicks
StopAtMaxTicks
0
1
-1000

CHOOSER
10
150
140
195
MaxTicks
MaxTicks
12 24 36 48 60 72 84 96 108 120 132 144 156 168 180 240
0

PLOT
320
465
780
585
Allowances
NIL
NIL
0.0
0.0
1.0
0.0
true
true
"let t floor allowpool_new / 100\nset-plot-y-range t (t + 1)\n\nlet c MaxTicks\nset-plot-x-range 0 c\n" ""
PENS
"Allowances available" 1.0 0 -14439633 true "" "plot allowpool_new"
"Demand" 1.0 0 -2139308 true "" "plot demandpool"

SLIDER
10
535
182
568
StartPrice
StartPrice
0
0.05
0.0
0.0001
1
€
HORIZONTAL

TEXTBOX
15
580
185
645
Starting price for one allowance (in Euros). Default value: 0.02, which is 20€ per tonne of CO2.
12
0.0
1

MONITOR
915
565
1047
610
Current Total Demand
demandpool
2
1
11

BUTTON
140
755
200
788
Save
update_values_output
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SLIDER
10
655
200
688
IncomePercentAvailable
IncomePercentAvailable
0.05
0.3
0.15
0.01
1
NIL
HORIZONTAL

MONITOR
905
520
1010
565
Demand-Median
Median [demand / number_persons] of households
2
1
11

BUTTON
10
795
200
828
Delete saved files
carefully [ \n  file-delete \"Output-Agents.csv\"\n  file-delete \"Output-World.csv\"\n  foreach (range MaxTicks) [\n  x -> file-delete (word \"world-\" x \".csv\") ]\n] [\n]\n; file-delete \"world-*.csv\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
320
585
560
705
Allowances Price
NIL
NIL
0.0
10.0
0.0
0.5
true
false
"let t floor price\nset-plot-y-range t (t + 0.1)\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"default" 1.0 0 -16777216 true "" "plot price"

MONITOR
560
705
780
750
Achieved Reduction (in t of carbon)
precision (BeginDemand - sum [demand] of households) 1 / 1000
2
1
11

PLOT
555
585
780
705
Number of agents above allowance limit
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 0.1 0 -9276814 true "" "plot count households with [diff < 0]"

MONITOR
790
610
910
655
% Agents > threshold
precision (count households with [diff < 0] / NumberAgents * 100) 2
17
1
11

PLOT
790
15
1070
165
Distribution Profile Parameters
NIL
NIL
0.0
1.0
0.0
10.0
true
true
"" ""
PENS
"SocioEco" 0.01 0 -11085214 true "" "histogram [socio-ecological] of turtles"
"Econ" 0.01 0 -5825686 true "" "histogram [economic] of turtles"

TEXTBOX
15
695
210
736
% of income to be spend on carbon reduction and allowances, depending on income
11
0.0
1

PLOT
790
165
1070
315
Income distribution
NIL
NIL
0.0
6100.0
0.0
5.0
true
true
"" ""
PENS
"Econ" 0.1 0 -5825686 true "" "histogram [income] of turtles with [socio-ecological + 0.1 < economic] "
"SocioEco" 1.0 0 -11085214 true "" "histogram [income] of turtles with [socio-ecological > economic + 0.1] "

TEXTBOX
10
455
60
473
Restricted
10
0.0
1

TEXTBOX
160
450
210
468
Abundant
10
0.0
1

MONITOR
1115
520
1190
565
Demand Max
Max [demand / number_persons] of households
1
1
11

MONITOR
1195
520
1272
565
Demand Min
Min [demand / number_persons] of households
1
1
11

PLOT
320
705
555
840
Total Carbon Abatement (t)
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"let c MaxTicks\nset-plot-x-range 0 c\n" ""
PENS
"default" 1.0 0 -16777216 true "" "plot (BeginDemand - sum [demand] of households) / 1000"

MONITOR
560
750
780
795
Achieved Reduction (t/HH)
precision ((BeginDemand - sum [demand] of households)  / 1000 / NumberPersons ) 2
17
1
11

CHOOSER
160
95
307
140
ColorAgents
ColorAgents
"1_income" "2_Ecological" "3_numberpersons" "4_selling" "5_difference"
1

PLOT
1075
15
1275
165
Sold allowances
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Econ" 1.0 0 -5825686 true "" "plot sum [diff * economic / number_persons] of households with [actualSelling = true]"
"SocioEco" 1.0 0 -13840069 true "" "plot sum [diff * socio-ecological / number_persons] of households with [actualSelling = true]"

PLOT
1280
15
1580
165
Amount Carbon Abated
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Econ" 1.0 0 -5825686 true "" "plot sum [economic * (originald - demand) / number_persons] of households"
"SocioEco" 1.0 0 -13840069 true "" "plot sum [socio-ecological * (originald - demand) / number_persons] of households"

PLOT
1075
165
1275
315
Investments
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Econ" 1.0 0 -5825686 true "" "plot sum [economic * saving] of households / NumberPersons"
"SocioEco" 1.0 0 -13840069 true "" "plot sum [socio-ecological * saving] of households / NumberPersons"

PLOT
1280
165
1580
310
Average demand reduction: SocioEco vs. Econ (pronounced)
NIL
NIL
0.0
120.0
0.0
10.0
true
false
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Econ" 1.0 0 -5825686 true "" "plot mean [demand - originald] of turtles with [socio-ecological + 0.3 < economic] "
"SocEco" 1.0 0 -13840069 true "" "plot mean [demand - originald] of turtles with [socio-ecological > economic + 0.3] "

PLOT
1280
310
1580
460
Average investments: SocioEco vs. Econ (pronounced)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Econ" 1.0 0 -5825686 true "" "plot mean [saving] of households with [socio-ecological + 0.1 < economic] "
"SocioEco" 1.0 0 -13840069 true "" "plot mean [saving] of households with [socio-ecological > economic + 0.1] "

MONITOR
1045
565
1187
610
% HH selling allowances
precision (count households with [actualSelling = true] / NumberAgents * 100 ) 1
17
1
11

PLOT
1280
465
1580
615
Sold Allowances_1
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"default" 1.0 0 -16777216 true "" "plot sum [diff / number_persons] of households with [actualSelling = true]"

SLIDER
10
310
257
343
sensitivity
sensitivity
0
2
2.0
0.01
1
NIL
HORIZONTAL

PLOT
790
670
1335
845
True Reduction vs. Target
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"\nlet c MaxTicks\nset-plot-x-range 0 c" ""
PENS
"Average Reduction" 1.0 0 -14439633 true "" "plot averageReduce "
"Target Reduction" 1.0 0 -5298144 true "" "plot target"
"Allowance Reduction" 1.0 0 -7500403 true "" "plot target + sensitivity * (target - averageReduce)"

TEXTBOX
10
365
250
421
How much the difference between true reduction and target reduction is taken into account when reducing allowances
11
0.0
1

TEXTBOX
10
345
160
363
Constant Reduction
11
0.0
1

TEXTBOX
200
345
350
363
Adaptable\n
11
0.0
1

@#$#@#$#@
## WHAT IS IT?
A simulated approach for Personal Carbon Trading, for figuring out what effects it might have if it will be implemented in the real world. We use an artificial population with some empirical data from international literature and basic assumptions about heterogeneous energy demand. The model is NOT to be used as simulating the actual behavior of real populations, but a toy model to test the effects of differences in various factors such as number of agents, energy price, price of allowances, etc. It is important to adapt the model for specific countries as carbon footprint and energy demand determines the relative success of PCT. 

## HOW IT WORKS

Allowances to produce/generate carbon by fossil energy use are allocated to all agents. All agents receive the same number of allowances, that is, this simulation considers a PCT regime where all consumers are given the same carbon emission rights. Allowances can be traded to those agents whose demand is higher than allowances received. Hence, allowances get a price which roughly calculates from demand and supply. Agents can apply different strategies to reduce their amount of carbon by buying carbon saving appliances, reduce their carbon share by refraining from flying and car use and behavior change and invest in alternative energy systems (such as PV etc.).
A relatively higher level of socio-ecological and /or economic identity is necessary. Agents differ regarding these two variables following the consumat approach [1, 2]. 
An agent’s actual demand (at the simulation start) `actuald` for Car-bon/Energy basically depends on the number of people supposed to live in that specific household (number_persons, empiric distribution) as well as the income (income, empiric distribution). An agent’s share of the household’s allowances is called ‘Allowance’. The totals of both variables demand and allowance are `demandpool` and `allowpool`. 



## HOW TO USE IT

First, you might want to choose the number of ticks your Simulation is supposed to be valid. Notice the Switch somewhat directly behind the Chooser, disabling the limit. Since one tick is supposed to represent the time-span of one month, a sensible amount of ticks is somewhere at 120 Ticks (10 Years) to 180 Ticks (15 Years), or 60 Ticks (5 Years) for shorter term experiments. 
Probably the next thing you want to choose is the number of agents in the simulation run (use the NumberAgents chooser/slider). Note: this does not only amount to the total number of ‘people’ in this simulation, but also to the number of households with an empiric distribution of `number_persons`. From N = 4 there’s barely useful information to get (it was implemented and remained for detailed inspection and further development), With N > 10k the simulations may be slow, depending on your hardware. Use at own discretion. The market and the variables’ overall development (as well as price development) are more stable higher number of agents. 
The PercentReduction_Allow-Option is supposedly pretty simple rate: each year the allowed number will be reduced by (0/0.5/1/…) percent. Reasonable values here are 0 up to 5%, depending on how much is being allowed at the beginning. This ‘starting value’ can be modified by the slider for `AboveMean`. The amount of ‘allowed’ carbon/energy usage is then calculated taking the average ‘requirement’ of each agent, divided by the number of members in each ‘household’. Now, `AboveMean` provides the figure of how many percent above the mean the starting value is supposed to be. That is, with 10 % for instance, there will be – on average – 10% more allowances than – total – demand exists. However, since the allocation is independent from an agent’s individual demand, it turns out that some agents receive less than they would need and some receive more allowances. The default is 0%.
You may adapt the value for price per kWh as the starting price in the PCT-market. The Default value used is 0.02, but other prices can be more useful in other contexts/countries.
The data can be auto-saved at each tick (just check the AutoSave-Switch) or manually saved. There will be several *.csv files saved, namely one being called ‘world-.csv’, which can be imported using `import-world <filename>`, there’s an ‘Output-World.csv’ with general information about the world, and an ‘Output-Agents.csv’ with detailed information about each of the agents internal values. Please refer to the implementation for usage. 


## THINGS TO NOTICE

There are various output facilities for the user to track the ongoing simulation at runtime. First, what is called `View` depicts the generated households, symbolized as houses with different colors. Currently there are three different shadings implemented. Blue: coloring according to income, green according to degree of socio-ecological motivation, and orange according to number of household members. 
With >10000 agents this makes less sense, because the view is crowded, but generally it gives you an impression of how many agents are affected by the allowance cap: After simulation `Start` those agents with fewer allowances than demand, turn yellow ‘sad faces’. Those affected will stay yellow the whole simulation time. However, in the case their demand becomes less than their allowances (they manage to get below the threshold by buying allowances and/or reducing their demand) they turn to yellow houses again. One may turn off this visualization by removing the tick at `view updates` in the Interface tab row. 
On the right side of the 'View' there first diagram shows the development of the "Carbon Demand per Person (in HouseHolds)". Several lines indicate the max and min values (to get an impression of how high and low the values actually are), the average, the value of what is allowed and the possible min. Moreover, the values of four randomly chosen agents are shown - in the case only four agents have been initialized one can track the development of their values. For simulation runs with more agents, average and min/max make more sense, but of course the individual agent behavior maybe unique. You can also track specific agents by right clicking on one's symbol in the 'View', choosing `inspect household` (see for NetLogo Help: "inspect agent").
Below that graph different monitors show important values: 
- allowed carbon per person
- the demand's median and average (per person)
- the achieved actual total carbon reduction
Below that a diagram shows the development of the difference between averaged allowance - demand (per person).
The other graphs and monitors should be self explaining. 
You may notice that for the baseline simulation without yearly allowances reductions, there is still an achieved carbon reduction. This is because some households are trying to reduce their demand and take different measures. As intended by the policy, a reduction by X% increases (respectively maintains) the pressure on households to try a reduction. Of course there is a limit to this reduction efforts, either for economic reasons or by a minimum of energy use necessary for daily life. 



## THINGS TO TRY

By trying different initialization values for `PercentReduction_Allow` `AboveMean` by the sliders, you find that these two parameters have great influence on the agents' behavior and simulation results. 
By adjusting `AboveMean` for instance to values around 10. One can notice that the effect (e.g. on carbon saving) is limited. This is, because on average the households receive a comparatively convenient number of allowances and do not need to reduce their carbon footprint too much. On could then try different high values for the annual allowance reduction, to introduce some stress on the agents. The higher the number of agents (> 100), the more likely it is that some of them fall short on allowances already at the start. However, if there would not be an annual reduction, carbon savings basically are determined by the agents' spontaneous reduction behavior. 
Contrary to that, an annual reduction of 5% of allowances results in an increasing number of households above their allowed threshold and hence a higher number of sold allowances (and allowance price) over time. In general one can observe that higher % levels of reduction result in more trading activity after the annual turn and a following sharp decrease (note the saw tooth-pattern, triggered by the annual decreases). 
Without annual reduction but lower starting value `AboveMean` (say 10%), the development shows a fairly smooth increase of sold allowances and a single peak of agents above the threshold shortly after the simulation starts. 
You may thus try: 
•	High `AboveMean` and low `PercentReduction_Allow`
•	High `AboveMean` and low `PercentReduction_Allow`
If you let the model run for a long time (> 200 ticks; e.g. for `AboveMean` = 10 % and `PercentReduction_Allow` = 1 %) you may observe that first only few allowances are sold, then increasingly more and then again fewer. Price is very low (virtually 0) for a longer time, until around tick 180 a first hump appears - this is when fewer allowances are traded. Why is that? One can assume that fewer allowances are on the 'market' because increasingly more households cross their own allowances level (as can be seen by the higher and higher peaks in the count households with [shape = "face sad"] graph). A bit later (just before tick 190) the price starts to skyrocket. Obviously demand becomes greater than the pool of allowances and the system does not work tom compensate for further and further annual decreases. 
With the model one could play around to determine for different starting values and population sizes and related success of the PCT in terms of investments and carbon abatement. Or the other way round, try to achieve different carbon saving levels with specific parameter settings.



## EXTENDING THE MODEL
The Market might not be as sophisticated as required for more elaborated economic experiments (see for instance [3]). We used the simplest reasonable form of calculating allowances price, extension are definitely possible [4].
Moreover, to adapt the artificially generic assumptions and agents to a certain empirical population, for instance in a certain country or city, one has to use empirical data. As Moglia et al. (2018) [5] say about their model on energy efficiency adoption that it “should be viewed as a conceptual structure with a theoretical and empirical grounding, but which requires further data collection for rigorous analysis of policy options.” This is also true for this model on adoption of PCT. 
Moreover, applying the model to specific market contexts or countries with different carbon footprints of households and demand, needs data collection for income distribution, allowances price, gCO2/kWh, etc. 


## NETLOGO FEATURES

# none specific #


## RELATED MODELS

There are some (also agent based) computer models on PCT, but as the concept is rather conceptual to date, empirical data to feed the models are scarce. Hence, most models are fairly conceptual, too. Moreover, there are various possible ways to implement a PCT regime (e.g. mandatory or not, temporally constrained, etc.). Anyway, the purpose also of this model is to foster “what if” – like simulation experiments, to gain a better understanding of the effects of different possible implementations of a PCT regime. You may refer for instance to the following publications: 
Burgess, M. (2016). Personal carbon allowances: A revised model to alleviate distributional issues. Ecological Economics, 130(Supplement C), 316-327. doi: https://doi.org/10.1016/j.ecolecon.2016.08.002
Capstick, S. B., & Lewis, A. (2010). Effects of personal carbon allowances on decision-making: evidence from an experimental simulation. Climate Policy, 10(4), 369-384. doi: 10.3763/cpol.2009.0034
Fan, J., Li, Y., Wu, Y., Wang, S., & Zhao, D. (2016). Allowance trading and energy consumption under a personal carbon trading scheme: a dynamic programming approach. Journal of Cleaner Production, 112(Part 5), 3875-3883. doi: https://doi.org/10.1016/j.jclepro.2015.07.030
Fan, J. I. N., Wang, S., Wu, Y., Li, J. U. N., & Zhao, D. (2015). ENERGY-USE CHOICES AND ALLOWANCE TRADING UNDER THE PERSONAL CARBON TRADING SCHEME. Natural Resource Modeling, 28(1), 1-17. doi: 10.1111/nrm.12054
Kempener, R. (2009). Simulating personal carbon trading: An agent-based model. Science and Technology Policy Research Electronic Working Paper Series, University of Sussex, UK.
Lee, T., Yao, R., & Coker, P. (2014). An analysis of UK policies for domestic energy reduction using an agent based tool. Energy Policy, 66(Supplement C), 267-279. doi: https://doi.org/10.1016/j.enpol.2013.11.004
Lee, T., Yao, R., & Coker, P. (2014). An analysis of UK policies for domestic energy reduction using an agent based tool. Energy Policy, 66(Supplement C), 267-279. doi: https://doi.org/10.1016/j.enpol.2013.11.004
Li, J., Fan, J., Zhao, D., & Wang, S. (2015). Allowance price and distribu-tional effects under a personal carbon trading scheme. Journal of Cleaner Production, 103, 319-329. doi:https://doi.org/10.1016/j.jclepro.2014.08.081
Tang, L., Wu, J., Yu, L., & Bao, Q. (2015). Carbon emissions trading scheme exploration in China: A multi-agent-based model. Energy Policy, 81(Supplement C), 152-169. doi: https://doi.org/10.1016/j.enpol.2015.02.032




## CREDITS AND REFERENCES
### Empirical values based on findings from these studies: ###
1.	Federal Environment Office (2016). Representative survey of per capita consumption of natural resources in Germany. Source: https://www.umweltbundesamt.de/sites/default/files/medien/1410/publikationen/texte_39_2016_repraesentative_erhebung_von_pro-kopf-verbraeuchen_natuerlicher_ressourcen_korr.pdf 
2.	LeBaron, B. (2001): A builder’s guide to agent-based financial markets. In: Quantitative Finance 1 (2), S. 254–261. DOI: 10.1088/1469-7688/1/2/307. 
3.	Wallace, Andrew A.; Irvine, Katherine N.; Wright, Andrew J.; Fleming, Paul D. (2010): Public attitudes to personal carbon allowances. findings from a mixed-method study. In: Climate Policy 10 (4), S. 385–409. DOI: 10.3763/cpol.2009.0040.
4.	Zanni, Alberto M.; Bristow, Abigail L.; Wardman, Mark (2013): The potential behavioural effect of personal carbon trading. results from an experimental survey. In: Journal of Environmental Economics and Policy 2 (2), S. 222–243. DOI: 10.1080/21606544.2013.782471.


### Cited research: ###
[1] Jager, W. and M. Janssen, An updated conceptual framework for integrated modeling of human decision making: The Consumat II, in Workshop Complexity in the Real World @ ECCS - from policy intelligence to intelligent policy. 2012: Brussels. p. 1-18.
[2] Janssen, M.A. and W. Jager, Stimulating diffusion of green products. Journal of Evolutionary Economics, 2002. 12(3): p. 283-306.
[3] Li, J., et al., Allowance price and distributional effects under a personal carbon trading scheme. Journal of Cleaner Production, 2015. 103(Supplement C): p. 319-329.
[4] LeBaron, B., A builder's guide to agent-based financial markets. Quantitative Finance, 2001. 1(2): p. 254-261.
[5] Moglia, M., A. Podkalicka, and J. McGregor, An Agent-Based Model of Residential Energy Efficiency Adoption. Journal of Artificial Societies & Social Simulation, 2018. 21(3).
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.2-beta2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>start</go>
    <timeLimit steps="180"/>
    <metric>avgPrice</metric>
    <metric>avgAllowance</metric>
    <metric>avgSelling</metric>
    <metric>avgPoorSelling</metric>
    <enumeratedValueSet variable="NumberAgents">
      <value value="1000"/>
      <value value="50000"/>
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="MaxTicks">
      <value value="12"/>
      <value value="36"/>
      <value value="60"/>
      <value value="120"/>
    </enumeratedValueSet>
    <steppedValueSet variable="StartPrice" first="0" step="0.01" last="0.05"/>
    <steppedValueSet variable="IncomePercentAvailable" first="0.1" step="0.05" last="0.3"/>
    <enumeratedValueSet variable="Allocation_of_allowances">
      <value value="-10"/>
      <value value="-5"/>
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="sensitivity" first="0" step="0.25" last="2"/>
    <steppedValueSet variable="target" first="0" step="1" last="5"/>
    <enumeratedValueSet variable="StopAtMaxTicks">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="abbreviated-experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>start</go>
    <timeLimit steps="180"/>
    <metric>avgPrice</metric>
    <metric>avgAllowance</metric>
    <metric>avgSelling</metric>
    <metric>avgPoorSelling</metric>
    <metric>precision ((BeginDemand - sum [demand] of households)  / 1000 / NumberPersons ) 2</metric>
    <enumeratedValueSet variable="NumberAgents">
      <value value="1000"/>
      <value value="25000"/>
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="MaxTicks">
      <value value="12"/>
      <value value="36"/>
      <value value="60"/>
      <value value="120"/>
    </enumeratedValueSet>
    <steppedValueSet variable="StartPrice" first="0" step="0.01" last="0.05"/>
    <steppedValueSet variable="IncomePercentAvailable" first="0.1" step="0.05" last="0.3"/>
    <enumeratedValueSet variable="Allocation_of_allowances">
      <value value="-10"/>
      <value value="-5"/>
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="sensitivity" first="0" step="0.25" last="2"/>
    <steppedValueSet variable="target" first="0" step="1" last="5"/>
    <enumeratedValueSet variable="StopAtMaxTicks">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="finish experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>start</go>
    <timeLimit steps="180"/>
    <metric>avgPrice</metric>
    <metric>avgAllowance</metric>
    <metric>avgSelling</metric>
    <metric>avgPoorSelling</metric>
    <enumeratedValueSet variable="NumberAgents">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="MaxTicks">
      <value value="12"/>
      <value value="36"/>
      <value value="60"/>
      <value value="120"/>
    </enumeratedValueSet>
    <steppedValueSet variable="StartPrice" first="0" step="0.01" last="0.05"/>
    <steppedValueSet variable="IncomePercentAvailable" first="0.1" step="0.05" last="0.3"/>
    <enumeratedValueSet variable="Allocation_of_allowances">
      <value value="-10"/>
      <value value="-5"/>
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="sensitivity" first="0" step="0.25" last="2"/>
    <steppedValueSet variable="target" first="0" step="1" last="5"/>
    <enumeratedValueSet variable="StopAtMaxTicks">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment2" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="NumberAgents">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Allocation_of_allowances">
      <value value="-10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sensitivity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="MaxTicks">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ColorAgents">
      <value value="&quot;2_Ecological&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AutoSave">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="StartPrice">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="StopAtMaxTicks">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="IncomePercentAvailable">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
